==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/AbsoluteVolumeOscillatorIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { AbsoluteVolumeOscillatorIndicatorDescription } from "./AbsoluteVolumeOscillatorIndicatorDescription";
/**
 * @hidden
 */
export let AbsoluteVolumeOscillatorIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class AbsoluteVolumeOscillatorIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (AbsoluteVolumeOscillatorIndicatorDescriptionMetadata.a == null) {
                AbsoluteVolumeOscillatorIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                AbsoluteVolumeOscillatorIndicatorDescriptionMetadata.c(AbsoluteVolumeOscillatorIndicatorDescriptionMetadata.a);
            }
            if (a.j(AbsoluteVolumeOscillatorIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.y(AbsoluteVolumeOscillatorIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
            a.item("ShortPeriod", "Number:int");
            a.item("LongPeriod", "Number:int");
        }
        static d(a) {
            AbsoluteVolumeOscillatorIndicatorDescriptionMetadata.b(a);
            a.aa("AbsoluteVolumeOscillatorIndicator", () => new AbsoluteVolumeOscillatorIndicatorDescription());
            a.z("AbsoluteVolumeOscillatorIndicator", AbsoluteVolumeOscillatorIndicatorDescriptionMetadata.a);
        }
    }
    AbsoluteVolumeOscillatorIndicatorDescriptionMetadata.$t = /*@__PURE__*/ markType(AbsoluteVolumeOscillatorIndicatorDescriptionMetadata, 'AbsoluteVolumeOscillatorIndicatorDescriptionMetadata');
    AbsoluteVolumeOscillatorIndicatorDescriptionMetadata.a = null;
    return AbsoluteVolumeOscillatorIndicatorDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/AbsoluteVolumeOscillatorIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { AbsoluteVolumeOscillatorIndicatorDescription } from "./AbsoluteVolumeOscillatorIndicatorDescription";
/**
 * @hidden
 */
export let AbsoluteVolumeOscillatorIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class AbsoluteVolumeOscillatorIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (AbsoluteVolumeOscillatorIndicatorDescriptionMetadata.a == null) {
                AbsoluteVolumeOscillatorIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                AbsoluteVolumeOscillatorIndicatorDescriptionMetadata.c(AbsoluteVolumeOscillatorIndicatorDescriptionMetadata.a);
            }
            if (a.k(AbsoluteVolumeOscillatorIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.aa(AbsoluteVolumeOscillatorIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
            a.item("ShortPeriod", "Number:int");
            a.item("LongPeriod", "Number:int");
        }
        static d(a) {
            AbsoluteVolumeOscillatorIndicatorDescriptionMetadata.b(a);
            a.ac("AbsoluteVolumeOscillatorIndicator", () => new AbsoluteVolumeOscillatorIndicatorDescription());
            a.ab("AbsoluteVolumeOscillatorIndicator", AbsoluteVolumeOscillatorIndicatorDescriptionMetadata.a);
        }
    }
    AbsoluteVolumeOscillatorIndicatorDescriptionMetadata.$t = /*@__PURE__*/ markType(AbsoluteVolumeOscillatorIndicatorDescriptionMetadata, 'AbsoluteVolumeOscillatorIndicatorDescriptionMetadata');
    AbsoluteVolumeOscillatorIndicatorDescriptionMetadata.a = null;
    return AbsoluteVolumeOscillatorIndicatorDescriptionMetadata;
})();
